<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html lang="en" xml:lang="en" xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type"/>
{% block header %}{% endblock %}
    <title>{{ theme_root_title|striptags }}: {{ title|striptags }}</title>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
{{ metatags }}
{% include 'css.html' %}
{%- for cssfile in css_files %}
<link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
{%- endfor %}
{%- for js in script_files %}
<script type="text/javascript" src="{{ pathto(js, 1) }}"></script>
{%- endfor %}
  {# FAVICON #}
{% if favicon %}
    <link rel="shortcut icon" href="{{ pathto('_static/favicon.ico') }}"/>
{% endif %}
{% if theme_analytics_tracking_code %}
<!-- Google Analytics -->
<script>
(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
})(window,document,'script','//www.google-analytics.com/analytics.js','ga');

ga('create', '{{ theme_analytics_tracking_code }}', 'auto');
ga('send', 'pageview');
</script>
<!-- End Google Analytics -->
{% endif %}
  </head>
  <body>
{% include 'header.html' %}
    <div class="container docs-book-wrapper">
      <div class="row">
        <div class="col-lg-9 col-md-8 col-sm-8 col-lg-push-3 col-md-push-4 col-sm-push-4">
{% include 'titlerow.html' %}
          <div class="row">
            <div class="col-lg-12">
              <div class="docs-body" role="main">
{% block body %}{% endblock %}
              </div>
            </div>
          </div>
          <div class="docs-actions">
          {% if prev %}
            <a href="{{ prev.link|e }}"><i class="fa fa-angle-double-left" data-toggle="tooltip" data-placement="top" title="Previous: {{ prev.title|striptags }}"></i></a>
          {% endif %}
          {% if next %}
            <a href="{{ next.link|e }}"><i class="fa fa-angle-double-right" data-toggle="tooltip" data-placement="top" title="Next: {{ next.title|striptags }}"></i></a>
          {% endif %}
          {%- if pdf_link %}
          <a id="pdfLink2" href="" target="_blank" title="Download the manuals as PDF"><i class="fa fa-file-pdf-o" data-toggle="tooltip" data-placement="top" title="Download PDF"></i></a>
          {% endif %}
          {%- if bug_project %}
            <a id="logABugLink3" href="" target="_blank" title="Found an error? Report a bug against this page"><i class="fa fa-bug" data-toggle="tooltip" data-placement="top" title="Report a Bug"></i></a>
          {% endif %}
          </div>
          <div class="row docs-byline bottom">
            <div class="docs-updated">this page last updated: {{ last_updated }}</div>
          </div>
          <div class="row">
            <div class="col-lg-8 col-md-8 col-sm-8 docs-license">
{% include 'license_cc.html' %}
            </div>
            <div class="col-lg-4 col-md-4 col-sm-4 docs-actions-wrapper">
            <!-- ID buglinkbottom added so that pre-filled doc bugs
                 are sent to Launchpad projects related to the
                 document -->
              {%- if bug_project %}
              <a href="#" id="logABugLink2" class="docs-footer-actions"><i class="fa fa-bug"></i> found an error? report a bug</a>
              {%- endif %}
              <a href="https://ask.openstack.org" class="docs-footer-actions"><i class="fa fa-question-circle"></i> questions?</a>
            </div>
          </div>
        </div>
{% include 'sidebartoc.html' %}
      </div>
    </div>
{% include 'footer.html' %}
{% include 'script_footer.html' %}
{% block script_footer %}{% endblock %}
{% if display_badge %}
<script type="text/javascript">
    $(document).ready(function(){

          $.ajax({
            context: this,
            dataType : "html",
            url : "https://docs.openstack.org/{{ series }}/badge.html",
            success : function(results) {
                $('#deprecated-badge-container').html(results);
            }
        });
    });
</script>
<div id="deprecated-badge-container"></div>
{% endif %}
  </body>
</html>
